# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2022 Technische Universität Graz
#
# invenio-rdm-pure is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Invenio module that adds pure."""

from setuptools import setup

setup()
